function importtable = importtable(workbookFile,sheetName,startRow,endRow)

%IMPORTFILE Import data from a spreadsheet
%   DATA = IMPORTFILE(FILE) reads data from the first worksheet in the
%   Microsoft Excel spreadsheet file named FILE and returns the data as a
%   table.
%
%   DATA = IMPORTFILE(FILE,SHEET) reads from the specified worksheet.
%
%   DATA = IMPORTFILE(FILE,SHEET,STARTROW,ENDROW) reads from the specified
%   worksheet for the specified row interval(s). Specify STARTROW and
%   ENDROW as a pair of scalars or vectors of matching size for
%   dis-contiguous row intervals. To read to the end of the file specify an
%   ENDROW of inf.%
% 
%   Example:
%   DataFiguresS3 = importfile('Data_Figures.xls','NIM',2,142);
%
%   See also XLSREAD.

%% Input handling

% If no sheet is specified, read first sheet
if nargin == 1 || isempty(sheetName)
    sheetName = 1;
end

% If row start and end points are not specified, define defaults
if nargin <= 3
    startRow = 2;
    endRow = 142;
end

%% Import the data, extracting spreadsheet dates in Excel serial date format

[~, ~, raw, dates] = xlsread(workbookFile, sheetName, sprintf('A%d:G%d',startRow(1),endRow(1)),'' , @convertSpreadsheetExcelDates);

for block=2:length(startRow)
    [~, ~, tmpRawBlock,tmpDateNumBlock] = xlsread(workbookFile, sheetName, sprintf('A%d:G%d',startRow(block),endRow(block)),'' , @convertSpreadsheetExcelDates);
    raw = [raw;tmpRawBlock]; %#ok<AGROW>
    dates = [dates;tmpDateNumBlock]; %#ok<AGROW>
end
raw = raw(:,[2,3,4,5,6,7]);
dates = dates(:,1);

%% Create output variable

I = cellfun(@(x) ischar(x), raw);
raw(I) = {NaN};
data = reshape([raw{:}],size(raw));

%% Create table

importtable = table;

%% Allocate imported array to column variable names

dates(~cellfun(@(x) isnumeric(x) || islogical(x), dates)) = {NaN};
importtable.date = datetime([dates{:,1}].', 'ConvertFrom', 'Excel');
importtable.var1 = data(:,1);
importtable.var2 = data(:,2);
importtable.var3 = data(:,3);  
importtable.var4 = data(:,4);
importtable.var5 = data(:,5);
importtable.var6 = data(:,6);

% For code requiring serial dates (datenum) instead of datetime, uncomment
% the following line(s) below to return the imported dates as datenum(s).

% importtable.date=datenum(importtable.date);

importtable = table2timetable(importtable);
